#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-qualify-imported-names-plugin
version:              2.3.0.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-2.3.0.0-CjSAD79j8E0CazDTWbO0ZA

key:
    hls-qualify-imported-names-plugin-2.3.0.0-CjSAD79j8E0CazDTWbO0ZA

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8a95db40e27424feeab9ce18b516e419
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-qualify-imported-names-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-2.3.0.0-CjSAD79j8E0CazDTWbO0ZA

depends:
    aeson-2.2.1.0-1TOI5ELuqi01VCY8v7ADie base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 dlist-1.0-B7D1vsARFiIHVaGk5CGbYO ghc-9.6.6
    ghcide-2.3.0.0-IerisuWePdB5VcUEKGdBma
    hls-graph-2.3.0.0-17aFD99Unw6K15Q2HZVh0V
    hls-plugin-api-2.3.0.0-4bP3yEhXwepGzPv2FsJuVz
    lens-5.3.4-kk6OqUq8ZY4lLpzN7435U lsp-2.2.0.0-4Q318iNA7bh2z7DE4qCtN4
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-HfKtyefgs0b2egKrxLGXU0

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

